==> api-0.16.0-sources.jar: io/strimzi/api/kafka/model/listener/KafkaListenerAuthenticationOAuthBuilder.java <==
package io.strimzi.api.kafka.model.listener;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class KafkaListenerAuthenticationOAuthBuilder extends KafkaListenerAuthenticationOAuthFluentImpl<KafkaListenerAuthenticationOAuthBuilder> implements VisitableBuilder<KafkaListenerAuthenticationOAuth,KafkaListenerAuthenticationOAuthBuilder>{

    KafkaListenerAuthenticationOAuthFluent<?> fluent;
    Boolean validationEnabled;

    public KafkaListenerAuthenticationOAuthBuilder(){
            this(true);
    }
    public KafkaListenerAuthenticationOAuthBuilder(Boolean validationEnabled){
            this(new KafkaListenerAuthenticationOAuth(), validationEnabled);
    }
    public KafkaListenerAuthenticationOAuthBuilder(KafkaListenerAuthenticationOAuthFluent<?> fluent){
            this(fluent, true);
    }
    public KafkaListenerAuthenticationOAuthBuilder(KafkaListenerAuthenticationOAuthFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new KafkaListenerAuthenticationOAuth(), validationEnabled);
    }
    public KafkaListenerAuthenticationOAuthBuilder(KafkaListenerAuthenticationOAuthFluent<?> fluent,KafkaListenerAuthenticationOAuth instance){
            this(fluent, instance, true);
    }
    public KafkaListenerAuthenticationOAuthBuilder(KafkaListenerAuthenticationOAuthFluent<?> fluent,KafkaListenerAuthenticationOAuth instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withClientId(instance.getClientId());

            fluent.withClientSecret(instance.getClientSecret());

            fluent.withValidIssuerUri(instance.getValidIssuerUri());

            fluent.withJwksEndpointUri(instance.getJwksEndpointUri());

            fluent.withJwksRefreshSeconds(instance.getJwksRefreshSeconds());

            fluent.withJwksExpirySeconds(instance.getJwksExpirySeconds());

            fluent.withIntrospectionEndpointUri(instance.getIntrospectionEndpointUri());

            fluent.withUserNameClaim(instance.getUserNameClaim());

            fluent.withCheckAccessTokenType(instance.isCheckAccessTokenType());

            fluent.withAccessTokenIsJwt(instance.isAccessTokenIsJwt());

            fluent.withTlsTrustedCertificates(instance.getTlsTrustedCertificates());

            fluent.withDisableTlsHostnameVerification(instance.isDisableTlsHostnameVerification());

            this.validationEnabled = validationEnabled; 
    }
    public KafkaListenerAuthenticationOAuthBuilder(KafkaListenerAuthenticationOAuth instance){
            this(instance,true);
    }
    public KafkaListenerAuthenticationOAuthBuilder(KafkaListenerAuthenticationOAuth instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withClientId(instance.getClientId());

            this.withClientSecret(instance.getClientSecret());

            this.withValidIssuerUri(instance.getValidIssuerUri());

            this.withJwksEndpointUri(instance.getJwksEndpointUri());

            this.withJwksRefreshSeconds(instance.getJwksRefreshSeconds());

            this.withJwksExpirySeconds(instance.getJwksExpirySeconds());

            this.withIntrospectionEndpointUri(instance.getIntrospectionEndpointUri());

            this.withUserNameClaim(instance.getUserNameClaim());

            this.withCheckAccessTokenType(instance.isCheckAccessTokenType());

            this.withAccessTokenIsJwt(instance.isAccessTokenIsJwt());

            this.withTlsTrustedCertificates(instance.getTlsTrustedCertificates());

            this.withDisableTlsHostnameVerification(instance.isDisableTlsHostnameVerification());

            this.validationEnabled = validationEnabled; 
    }

    public KafkaListenerAuthenticationOAuth build(){
            KafkaListenerAuthenticationOAuth buildable = new KafkaListenerAuthenticationOAuth();
            buildable.setClientId(fluent.getClientId());
            buildable.setClientSecret(fluent.getClientSecret());
            buildable.setValidIssuerUri(fluent.getValidIssuerUri());
            buildable.setJwksEndpointUri(fluent.getJwksEndpointUri());
            buildable.setJwksRefreshSeconds(fluent.getJwksRefreshSeconds());
            buildable.setJwksExpirySeconds(fluent.getJwksExpirySeconds());
            buildable.setIntrospectionEndpointUri(fluent.getIntrospectionEndpointUri());
            buildable.setUserNameClaim(fluent.getUserNameClaim());
            buildable.setCheckAccessTokenType(fluent.isCheckAccessTokenType());
            buildable.setAccessTokenIsJwt(fluent.isAccessTokenIsJwt());
            buildable.setTlsTrustedCertificates(fluent.getTlsTrustedCertificates());
            buildable.setDisableTlsHostnameVerification(fluent.isDisableTlsHostnameVerification());
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            KafkaListenerAuthenticationOAuthBuilder that = (KafkaListenerAuthenticationOAuthBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> api-0.21.0-sources.jar: io/strimzi/api/kafka/model/listener/KafkaListenerAuthenticationOAuthBuilder.java <==
package io.strimzi.api.kafka.model.listener;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class KafkaListenerAuthenticationOAuthBuilder extends KafkaListenerAuthenticationOAuthFluentImpl<KafkaListenerAuthenticationOAuthBuilder> implements VisitableBuilder<KafkaListenerAuthenticationOAuth,KafkaListenerAuthenticationOAuthBuilder>{

    KafkaListenerAuthenticationOAuthFluent<?> fluent;
    Boolean validationEnabled;

    public KafkaListenerAuthenticationOAuthBuilder(){
            this(true);
    }
    public KafkaListenerAuthenticationOAuthBuilder(Boolean validationEnabled){
            this(new KafkaListenerAuthenticationOAuth(), validationEnabled);
    }
    public KafkaListenerAuthenticationOAuthBuilder(KafkaListenerAuthenticationOAuthFluent<?> fluent){
            this(fluent, true);
    }
    public KafkaListenerAuthenticationOAuthBuilder(KafkaListenerAuthenticationOAuthFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new KafkaListenerAuthenticationOAuth(), validationEnabled);
    }
    public KafkaListenerAuthenticationOAuthBuilder(KafkaListenerAuthenticationOAuthFluent<?> fluent,KafkaListenerAuthenticationOAuth instance){
            this(fluent, instance, true);
    }
    public KafkaListenerAuthenticationOAuthBuilder(KafkaListenerAuthenticationOAuthFluent<?> fluent,KafkaListenerAuthenticationOAuth instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withClientId(instance.getClientId());

            fluent.withClientSecret(instance.getClientSecret());

            fluent.withValidIssuerUri(instance.getValidIssuerUri());

            fluent.withCheckIssuer(instance.isCheckIssuer());

            fluent.withJwksEndpointUri(instance.getJwksEndpointUri());

            fluent.withJwksRefreshSeconds(instance.getJwksRefreshSeconds());

            fluent.withJwksMinRefreshPauseSeconds(instance.getJwksMinRefreshPauseSeconds());

            fluent.withJwksExpirySeconds(instance.getJwksExpirySeconds());

            fluent.withIntrospectionEndpointUri(instance.getIntrospectionEndpointUri());

            fluent.withUserNameClaim(instance.getUserNameClaim());

            fluent.withFallbackUserNameClaim(instance.getFallbackUserNameClaim());

            fluent.withFallbackUserNamePrefix(instance.getFallbackUserNamePrefix());

            fluent.withUserInfoEndpointUri(instance.getUserInfoEndpointUri());

            fluent.withCheckAccessTokenType(instance.isCheckAccessTokenType());

            fluent.withValidTokenType(instance.getValidTokenType());

            fluent.withAccessTokenIsJwt(instance.isAccessTokenIsJwt());

            fluent.withTlsTrustedCertificates(instance.getTlsTrustedCertificates());

            fluent.withDisableTlsHostnameVerification(instance.isDisableTlsHostnameVerification());

            fluent.withEnableECDSA(instance.isEnableECDSA());

            fluent.withMaxSecondsWithoutReauthentication(instance.getMaxSecondsWithoutReauthentication());

            this.validationEnabled = validationEnabled; 
    }
    public KafkaListenerAuthenticationOAuthBuilder(KafkaListenerAuthenticationOAuth instance){
            this(instance,true);
    }
    public KafkaListenerAuthenticationOAuthBuilder(KafkaListenerAuthenticationOAuth instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withClientId(instance.getClientId());

            this.withClientSecret(instance.getClientSecret());

            this.withValidIssuerUri(instance.getValidIssuerUri());

            this.withCheckIssuer(instance.isCheckIssuer());

            this.withJwksEndpointUri(instance.getJwksEndpointUri());

            this.withJwksRefreshSeconds(instance.getJwksRefreshSeconds());

            this.withJwksMinRefreshPauseSeconds(instance.getJwksMinRefreshPauseSeconds());

            this.withJwksExpirySeconds(instance.getJwksExpirySeconds());

            this.withIntrospectionEndpointUri(instance.getIntrospectionEndpointUri());

            this.withUserNameClaim(instance.getUserNameClaim());

            this.withFallbackUserNameClaim(instance.getFallbackUserNameClaim());

            this.withFallbackUserNamePrefix(instance.getFallbackUserNamePrefix());

            this.withUserInfoEndpointUri(instance.getUserInfoEndpointUri());

            this.withCheckAccessTokenType(instance.isCheckAccessTokenType());

            this.withValidTokenType(instance.getValidTokenType());

            this.withAccessTokenIsJwt(instance.isAccessTokenIsJwt());

            this.withTlsTrustedCertificates(instance.getTlsTrustedCertificates());

            this.withDisableTlsHostnameVerification(instance.isDisableTlsHostnameVerification());

            this.withEnableECDSA(instance.isEnableECDSA());

            this.withMaxSecondsWithoutReauthentication(instance.getMaxSecondsWithoutReauthentication());

            this.validationEnabled = validationEnabled; 
    }

    public KafkaListenerAuthenticationOAuth build(){
            KafkaListenerAuthenticationOAuth buildable = new KafkaListenerAuthenticationOAuth();
            buildable.setClientId(fluent.getClientId());
            buildable.setClientSecret(fluent.getClientSecret());
            buildable.setValidIssuerUri(fluent.getValidIssuerUri());
            buildable.setCheckIssuer(fluent.isCheckIssuer());
            buildable.setJwksEndpointUri(fluent.getJwksEndpointUri());
            buildable.setJwksRefreshSeconds(fluent.getJwksRefreshSeconds());
            buildable.setJwksMinRefreshPauseSeconds(fluent.getJwksMinRefreshPauseSeconds());
            buildable.setJwksExpirySeconds(fluent.getJwksExpirySeconds());
            buildable.setIntrospectionEndpointUri(fluent.getIntrospectionEndpointUri());
            buildable.setUserNameClaim(fluent.getUserNameClaim());
            buildable.setFallbackUserNameClaim(fluent.getFallbackUserNameClaim());
            buildable.setFallbackUserNamePrefix(fluent.getFallbackUserNamePrefix());
            buildable.setUserInfoEndpointUri(fluent.getUserInfoEndpointUri());
            buildable.setCheckAccessTokenType(fluent.isCheckAccessTokenType());
            buildable.setValidTokenType(fluent.getValidTokenType());
            buildable.setAccessTokenIsJwt(fluent.isAccessTokenIsJwt());
            buildable.setTlsTrustedCertificates(fluent.getTlsTrustedCertificates());
            buildable.setDisableTlsHostnameVerification(fluent.isDisableTlsHostnameVerification());
            buildable.setEnableECDSA(fluent.isEnableECDSA());
            buildable.setMaxSecondsWithoutReauthentication(fluent.getMaxSecondsWithoutReauthentication());
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            KafkaListenerAuthenticationOAuthBuilder that = (KafkaListenerAuthenticationOAuthBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
